<?php
namespace common\plugins\sms\smsbao;

use yii;

use common\models\SmsTemplateModel;

use common\library\Basewind;
use common\library\Language;
use common\plugins\BaseSms;

/**
 * @Id smsbao.plugin.php 2025.6.5 $
 * @author smsbao
 */

class Smsbao extends BaseSms
{
    /**
	 * 网关地址
	 * @var string $gateway
	 */
    protected $gateway = 'http://api.smsbao.com/';
    
	/**
     * 短信实例
	 * @var string $code
	 */
    protected $code = 'smsbao';
    protected $smbaostatus = [
        "0" => "短信发送成功",
        "-1" => "参数不全",
        "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
        "30" => "密码错误",
        "40" => "账号不存在",
        "41" => "余额不足",
        "42" => "帐户已过期",
        "43" => "IP地址限制",
        "50" => "内容含有敏感词"
];
    
    /**
	 * 发送短信
     * @param bool $valid 发送频次等的校验，如果是系统发送的短信，可以适当的不做该校验以确保发送成功
	 */
	public function send($valid = true)
	{
        if(!$this->verify()) {
            return false;
        }
      
        if($valid === true && !$this->validSend()) {
            return false;
        }
        
        // 发送的短信信息校验
        if($this->validData() == false) {
            return false;
        }
  
        $result = $this->submit();
        if($result == '0') {
            $codekey = $this->insert($result);
            return $codekey;
        }

        $this->errors = $this->smbaostatus[$result];
        $this->insert(0, $this->errors);
        return false;
    }

    /**
     * 测试短信发送
     */
    public function testsend($content = '') {
        $this->content = $content;
        $result = $this->submit();
        if($result == '0') {
            return true;
        }

        $this->errors = $this->smbaostatus[$result];
        return false;
    }
    
    /**
     * 执行短信发生
     */
    private function submit()
    {
        $url = $this->gateway.'sms?u='.$this->config['uid'].'&p='.$this->config['ApiKey'] .
        '&m=' . $this->receiver . '&c=' . urlencode('【'.$this->signName.'】'.$this->content);
        return Basewind::curl($url);
    }

    /**
     * 检测是否配置
     * @var boolean $force 是否验证短信模板内容
     */
    public function verify($force = true)
    {
        if(!$this->config['uid']) {
            $this->errors = '短信设置错误';
            return false;
        }
        if(!$this->config['ApiKey']) {
            $this->errors = '短信设置错误';
            return false;
        }

        // 如果是验证非具体短信场景，可以不用验证短信模板
        // 比如某个地方仅仅需要判断密钥是否配置，从而进行开关控制
        if(!$force) {
            return true;
        }

        // 传递具体短信场景参数，则验证短信模板
        if(($template = $this->getTemplate()) === false) {
            return false;
        }
        if(!$template || empty($template->content)) {
            $this->errors = Language::get('The "content" property must be set');
            return false;
        }
        if(empty($template->signName)) {
            $this->errors = Language::get('The "signName" property must be set');
            return false;
        }

        // 此处为必须赋值，避免无法发送短信
        $this->templateId = $template->templateId;
        $this->signName = $template->signName;
        $this->content = $this->getContent($template);

        return true;
    }
    
}

